@@ -1,18 +1,17 @@
-
 =head1 NAME
 
 Set::Object - set of objects and strings
 
 =head1 SYNOPSIS
 
-  use Set::Object;
+  use Set::Object qw(set);
 
   my $set = set();            # or Set::Object->new()
 
   $set->insert(@thingies);
   $set->remove(@thingies);
 
-  @items = @$set;             # or $set->members;
+  @items = @$set;             # or $set->members for the unsorted array
 
   $union = $set1 + $set2;
   $intersection = $set1 * $set2;
@@ -97,7 +96,7 @@ to explicitly import this method.
 Add items to the C<Set::Object>.
 
 Adding the same object several times is not an error, but any
-C<Set::Object> will contain at most one occurence of the same object.
+C<Set::Object> will contain at most one occurrence of the same object.
 
 Returns the number of elements that were actually added.  As of
 Set::Object 1.23, C<undef> will not insert.
@@ -130,6 +129,9 @@ item if the value is found, rather than just a true value.
 Return the objects contained in the C<Set::Object> in random (hash)
 order.
 
+Note that the elements of a C<Set::Object> in list context are returned
+sorted - C<@$set> - so using the C<members> method is much faster.
+
 =head2 size
 
 Return the number of elements in the C<Set::Object>.
@@ -492,18 +494,20 @@ Tickets at RT L<https://rt.cpan.org/Public/Dist/Display.html?Name=Set-Object>
 
 Copyright (c) 1998-1999, Jean-Louis Leroy. All Rights Reserved.
 This module is free software. It may be used, redistributed
-and/or modified under the terms of the Perl Artistic License
+and/or modified under the terms of the Perl Artistic License, either the
+original, or at your option, any later version.
 
 Portions Copyright (c) 2003 - 2005, Sam Vilain.  Same license.
 
-Portions Copyright (c) 2006, 2007, Catalyst IT (NZ) Limited.  Same
-license.
+Portions Copyright (c) 2006, 2007, Catalyst IT (NZ) Limited.  This
+module is free software. It may be used, redistributed and/or modified
+under the terms of the Perl Artistic License
 
 Portions Copyright (c) 2013, cPanel.  Same license.
 
 =head1 SEE ALSO
 
-perl(1), perltie(1), L<Set::Scalar>, overload.pm
+perl(1), perltie(1), L<Set::Scalar>, L<overload>
 
 =cut
 
@@ -524,7 +528,7 @@ require AutoLoader;
 
 @EXPORT_OK = qw( ish_int is_int is_string is_double blessed reftype
 		 refaddr is_overloaded is_object is_key set weak_set );
-$VERSION = '1.32';
+$VERSION = '1.36';
 
 bootstrap Set::Object $VERSION;
 
@@ -760,6 +764,7 @@ sub tie_array_pkg { "Set::Object::TieArray" };
       Scalar::Util::weaken($tie->[1]);
       return $tie;
   }
+  # note the sort here
   sub promote {
       my $self = shift;
       @{$self->[0]} = sort $self->[1]->members;
